<?php
include("api.php");
header('Content-Type: application/json');

$limit = isset($_GET['limit']) ? intval($_GET['limit']) : 20;
$offset = isset($_GET['offset']) ? intval($_GET['offset']) : 0;
$order = isset($_GET['order']) ? $_GET['order'] : 'id';
$orderType = isset($_GET['orderType']) ? strtoupper($_GET['orderType']) : 'DESC';
$category_id = isset($_GET['category_id']) ? intval($_GET['category_id']) : null;

$allowedOrderFields = [
    'id', 'lang_id', 'title', 'title_slug', 'title_hash', 'keywords', 'summary', 'content', 
    'category_id', 'image_big', 'image_default', 'image_slider', 'image_mid', 'image_small', 
    'image_mime', 'image_storage', 'optional_url', 'pageviews', 'need_auth', 'is_slider', 
    'slider_order', 'is_featured', 'featured_order', 'is_recommended', 'is_breaking', 
    'is_scheduled', 'visibility', 'show_right_column', 'post_type', 'video_path', 'video_storage', 
    'image_url', 'video_url', 'video_embed_code', 'user_id', 'status', 'feed_id', 'post_url', 
    'show_post_url', 'image_description', 'show_item_numbers', 'is_poll_public', 'updated_at', 
    'created_at'
];

if (!in_array($order, $allowedOrderFields)) {
    $order = 'id';
}

if ($orderType !== 'DESC' && $orderType !== 'ASC') {
    $orderType = 'DESC';
}
date_default_timezone_set('Asia/Kolkata');

$currentDateTime = new DateTime('now');
$currentDate = $currentDateTime->format('Y-m-d H:i:s');
 
$sql = "SELECT * FROM posts WHERE created_at <= $currentDate";
$params = [];

if ($category_id !== null) {
    $sql .= " AND category_id = ?";
    $params[] = $category_id;
}

$sql .= " ORDER BY $order $orderType LIMIT ? OFFSET ?";
$params[] = $limit;
$params[] = $offset;

$stmt = $conn->prepare($sql);

if ($category_id !== null) {
    // Binding parameters for category_id, limit, and offset
    $stmt->bind_param("iii", $params[0], $params[1], $params[2]);
} else {
    // Binding parameters for limit and offset only
    $stmt->bind_param("ii", $params[1], $params[2]);
}

$stmt->execute();
$result = $stmt->get_result();

$posts = [];

if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $posts[] = $row;
    }
}

echo json_encode($posts);

$stmt->close();
$conn->close();

?>
