<?php
include("api.php");
header('Content-Type: application/json');

// Retrieve and sanitize input parameters
$limit = isset($_GET['limit']) ? intval($_GET['limit']) : 20;
$offset = isset($_GET['offset']) ? intval($_GET['offset']) : 0;
$order = isset($_GET['order']) ? $_GET['order'] : 'id';
$orderType = isset($_GET['orderType']) ? strtoupper($_GET['orderType']) : 'DESC';
$category_id = isset($_GET['category_id']) ? intval($_GET['category_id']) : null;
$post_id = isset($_GET['post_id']) ? intval($_GET['post_id']) : null;
$no_catid = isset($_GET['no_catid']) ? intval($_GET['no_catid']) : null;

// Define allowed fields for ordering
$allowedOrderFields = [
    'id', 'lang_id', 'title', 'title_slug', 'title_hash', 'keywords', 'summary', 'content', 
    'category_id', 'image_big', 'image_default', 'image_slider', 'image_mid', 'image_small', 
    'image_mime', 'image_storage', 'optional_url', 'pageviews', 'need_auth', 'is_slider', 
    'slider_order', 'is_featured', 'featured_order', 'is_recommended', 'is_breaking', 
    'is_scheduled', 'visibility', 'show_right_column', 'post_type', 'video_path', 'video_storage', 
    'image_url', 'video_url', 'video_embed_code', 'user_id', 'status', 'feed_id', 'post_url', 
    'show_post_url', 'image_description', 'show_item_numbers', 'is_poll_public', 'updated_at', 
    'created_at'
];

// Validate and sanitize order field and order type
$order = in_array($order, $allowedOrderFields) ? $order : 'id';
$orderType = ($orderType === 'DESC' || $orderType === 'ASC') ? $orderType : 'DESC';
date_default_timezone_set('Asia/Kolkata');

$currentDateTime = new DateTime('now');
$currentDate = $currentDateTime->format('Y-m-d H:i:s');
 
// Base SQL query
echo  $sql = "SELECT p.*, u.username, c.name 
        FROM posts p
        JOIN users u ON p.user_id = u.id
        JOIN categories c ON p.category_id = c.id 
        WHERE p.created_at <= '".$currentDate."' AND p.status = 1 ";

// Initialize parameters array
$params = [];
$types = '';

// Add conditions based on input parameters
if ($post_id !== null) {
    $sql .= " AND p.id = ?";
    $params[] = $post_id;
    $types .= 'i';
}
if ($category_id !== null) {
    $sql .= " AND p.category_id = ?";
    $params[] = $category_id;
    $types .= 'i';
}
if ($no_catid !== null) {
    $sql .= " AND p.category_id != ?";
    $params[] = $no_catid;
    $types .= 'i';
}

// Add ordering and limit/offset
$sql .= " ORDER BY p.$order $orderType LIMIT ? OFFSET ?";
$params[] = $limit;
$params[] = $offset;
$types .= 'ii';

try {
    // Prepare and execute SQL statement
    $stmt = $conn->prepare($sql);

    if (!empty($params)) {
        $stmt->bind_param($types, ...$params);
    }

    $stmt->execute();
    $result = $stmt->get_result();

    // Fetch results
    $posts = [];
    if ($result->num_rows > 0) {
        while ($row = $result->fetch_assoc()) {
            $posts[] = $row;
        }
    }

    // Output results as JSON
    echo json_encode($posts);

    $stmt->close();
} catch (Exception $e) {
    // Handle any errors
    echo json_encode(['error' => $e->getMessage()]);
}

// Close database connection
$conn->close();
?>
