<?php
header("Content-Type: application/json");
 
 

class CategoriesAPI {
    private $db;
    private $table = 'maga_type'; 

    public function __construct() {
        $database = new Database();
        $this->db = $database->connect();
    }

    public function handleRequest() {
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            $this->getAllCategories();
        } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $this->createCategory();
        } else {
            $this->respondNotFound();
        }
    }

private function getAllCategories() {
    $headers = apache_request_headers(); 

    error_log(print_r($headers, true));  
    
    if (!isset($headers['Authorization'])) {
        echo json_encode(["status" => false, "message" => "No token provided"]);
        return;
    }

    $token = str_replace('Bearer ', '', $headers['Authorization']);
    $decoded = JWT::validateToken($token);

    if ($decoded) {
        $query = "SELECT * FROM " . $this->table;
        $result = $this->db->query($query);

        if ($result->num_rows > 0) {
            $categories = [];
            while ($row = $result->fetch_assoc()) {
                $categories[] = $row;
            }
            echo json_encode(["status" => true, "data" => $categories]);
        } else {
            echo json_encode(["status" => false, "message" => "No categories found."]);
        }
    } else {
        echo json_encode(["status" => false, "message" => "Invalid or expired token"]);
    }
}


    private function createCategory() {
        $data = json_decode(file_get_contents("php://input"));

        if (empty($data->maga_type) || empty($data->maga_title)) {
            echo json_encode(["status" => false, "message" => "Type and title are required."]);
            return;
        }

        $query = "INSERT INTO " . $this->table . " (maga_type, maga_title) VALUES (?, ?)";
        $stmt = $this->db->prepare($query);
        $stmt->bind_param("ss", $data->maga_type, $data->maga_title);

        if ($stmt->execute()) {
            echo json_encode(["status" => true, "message" => "Category created successfully."]);
        } else {
            echo json_encode(["status" => false, "message" => "Failed to create category."]);
        }
    }

    private function respondNotFound() {
        echo json_encode(["status" => false, "message" => "Invalid request"]);
    }
}

$api = new CategoriesAPI();
$api->handleRequest();
?>
