<?php
header("Content-Type: application/json");
error_reporting(E_ALL);
ini_set('display_errors', 1);

class FcmtokenAPI {
    private $db;
    private $table = 'fcmtoken';  

    public function __construct() {
        $database = new Database();
        $this->db = $database->connect();
    }

    public function handleRequest() {
        if ($_SERVER['REQUEST_METHOD'] === 'GET') {
            $this->getAllTokens(); 
        } elseif ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $this->handlePostRequest();
        } else {
            $this->respondNotFound();
        }
    }

    private function handlePostRequest() {
        $request = explode('/', trim($_SERVER['REQUEST_URI'], '/')); 
        if (isset($request[2]) && $request[2] == 'notistatus') {
            $this->notiStatus();
        } else {
            $this->fcmtoken();
        }
    }

    private function fcmtoken() {
        $data = json_decode(file_get_contents("php://input"));

        if (empty($data->device_id) || empty($data->fcm_token)) {
            echo json_encode(["status" => false, "message" => "Device ID and FCM token are required."]);
            return;
        }

        $fcm_status = 'Yes';
        $fcm_date = date('Y-m-d H:i:s'); // Current date and time

        $query = "SELECT id FROM " . $this->table . " WHERE device_id = ?";
        $stmt = $this->db->prepare($query);
        if (!$stmt) {
            echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
            return;
        }

        $stmt->bind_param("s", $data->device_id);
        if (!$stmt->execute()) {
            echo json_encode(["status" => false, "message" => "Execute failed: " . $stmt->error]);
            return;
        }

        $stmt->store_result();
        if ($stmt->num_rows > 0) {
             $updateQuery = "UPDATE " . $this->table . " SET fcm_token = ?, fcm_status = ?, fcm_update = ? WHERE device_id = ?";
            $updateStmt = $this->db->prepare($updateQuery);
            if (!$updateStmt) {
                echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
                return;
            }

            $updateStmt->bind_param("ssss", $data->fcm_token, $fcm_status, $fcm_date, $data->device_id);
            if ($updateStmt->execute()) {
                echo json_encode(["status" => true, "message" => "Device token updated successfully."]);
            } else {
                echo json_encode(["status" => false, "message" => "Failed to update device token: " . $updateStmt->error]);
            }
        } else {
             $insertQuery = "INSERT INTO " . $this->table . " (device_id, fcm_token, fcm_status, fcm_date) VALUES (?, ?, ?, ?)";
            $insertStmt = $this->db->prepare($insertQuery);
            if (!$insertStmt) {
                echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
                return;
            }

            $insertStmt->bind_param("ssss", $data->device_id, $data->fcm_token, $fcm_status, $fcm_date);
            if ($insertStmt->execute()) {
                echo json_encode(["status" => true, "message" => "Device token inserted successfully."]);
            } else {
                echo json_encode(["status" => false, "message" => "Failed to insert device token: " . $insertStmt->error]);
            }
        }
    }

    private function notiStatus() {
        $data = json_decode(file_get_contents("php://input"));

        if (empty($data->device_id) || !isset($data->fcm_status)) {
            echo json_encode(["status" => false, "message" => "Device ID and FCM status are required."]);
            return;
        }

        $updateQuery = "UPDATE " . $this->table . " SET fcm_status = ?, fcm_date = NOW() WHERE device_id = ?";
        $updateStmt = $this->db->prepare($updateQuery);
        if (!$updateStmt) {
            echo json_encode(["status" => false, "message" => "Prepare statement failed: " . $this->db->error]);
            return;
        }

        $updateStmt->bind_param("ss", $data->fcm_status, $data->device_id);
        if ($updateStmt->execute()) {
            if ($updateStmt->affected_rows > 0) {
                echo json_encode(["status" => true, "message" => "Device status updated successfully."]);
            } else {
                echo json_encode(["status" => false, "message" => "Device ID not found."]);
            }
        } else {
            echo json_encode(["status" => false, "message" => "Failed to update device status."]);
        }
    }

    private function getAllTokens() {
        $query = "SELECT * FROM " . $this->table;
        $result = $this->db->query($query);

        if ($result->num_rows > 0) {
            $tokens = [];
            while ($row = $result->fetch_assoc()) {
                $tokens[] = $row;
            }
            echo json_encode(["status" => true, "data" => $tokens]);
        } else {
            echo json_encode(["status" => false, "message" => "No tokens found"]);
        }
    }

    private function respondNotFound() {
        echo json_encode(["status" => false, "message" => "Invalid request"]);
    }
}

$api = new FcmtokenAPI();
$api->handleRequest();
?>
