<?php
header("Content-Type: application/json");

require_once 'users.php'; 

class LoginAPI {
    private $db;
    private $user;

    public function __construct() {
        $database = new Database();
        $this->db = $database->connect();
        $this->user = new User($this->db);
    }

    public function handleRequest() {
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            $this->login();
        } else {
            $this->respondNotFound();
        }
    }

    private function login() {
        $data = json_decode(file_get_contents("php://input"));

        // Validate email and password presence
        if (empty($data->email) || empty($data->password)) {
            echo json_encode(["message" => "Email and password required."]);
            return;
        }

        $this->user->email = $data->email;
        $this->user->password = $data->password;

        $user = $this->user->login();

        if ($user) {
            // Generate JWT token with user information
            $token = JWT::createToken($user);

            // Generate a refresh token
            $refreshToken = JWT::createRefreshToken($user);

            // Save refresh token in the database (to validate later)
            // This is just a sample - you would save it to the user's record
            $this->user->saveRefreshToken($user['user_id'], $refreshToken);

            echo json_encode([
                "kstatus" => true, 
                "message" => "Login successful",
                "acctoken" => $token,
                "reftoken" => $refreshToken,
                "kdatas" => [
                    'Ucode' => $user['user_id'],
                    'Uemail' => $user['user_email'],
                    'Ufname' => $user['user_firstname'],
                ]
            ]);
        } else {
            echo json_encode(["message" => "Invalid email or password."]);
        }
    }

    private function respondNotFound() {
        echo json_encode(["message" => "Invalid request"]);
    }
}

$api = new LoginAPI();
$api->handleRequest();
?>
